diff --git a/polkadot/runtime/rococo/src/weights/polkadot_runtime_parachains_paras.rs b/polkadot/runtime/rococo/src/weights/polkadot_runtime_parachains_paras.rs
index ae2c4632aaaa6d61876f927b8df4a0a6758b707d..1d404a96f6f28abd25ba13fdb2110843d481dcce 100644
--- a/polkadot/runtime/rococo/src/weights/polkadot_runtime_parachains_paras.rs
+++ b/polkadot/runtime/rococo/src/weights/polkadot_runtime_parachains_paras.rs
@@ -17,9 +17,9 @@
 //! Autogenerated weights for `polkadot_runtime_parachains::paras`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 32.0.0
-//! DATE: 2025-02-17, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! DATE: 2025-02-27, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
 //! WORST CASE MAP SIZE: `1000000`
-//! HOSTNAME: `10b335e74d87`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
+//! HOSTNAME: `79347b363bdd`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
 //! WASM-EXECUTION: `Compiled`, CHAIN: `None`, DB CACHE: 1024
 
 // Executed Command:
@@ -68,11 +68,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `8309`
 		//  Estimated: `11774`
-		// Minimum execution time: 34_669_000 picoseconds.
-		Weight::from_parts(35_215_000, 0)
+		// Minimum execution time: 34_420_000 picoseconds.
+		Weight::from_parts(34_744_000, 0)
 			.saturating_add(Weight::from_parts(0, 11774))
-			// Standard Error: 98
-			.saturating_add(Weight::from_parts(11_135, 0).saturating_mul(c.into()))
+			// Standard Error: 135
+			.saturating_add(Weight::from_parts(13_652, 0).saturating_mul(c.into()))
 			.saturating_add(T::DbWeight::get().reads(4))
 			.saturating_add(T::DbWeight::get().writes(6))
 	}
@@ -83,11 +83,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 7_405_000 picoseconds.
-		Weight::from_parts(7_580_000, 0)
+		// Minimum execution time: 7_120_000 picoseconds.
+		Weight::from_parts(7_308_000, 0)
 			.saturating_add(Weight::from_parts(0, 0))
-			// Standard Error: 34
-			.saturating_add(Weight::from_parts(3_820, 0).saturating_mul(s.into()))
+			// Standard Error: 41
+			.saturating_add(Weight::from_parts(4_583, 0).saturating_mul(s.into()))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
 	/// Storage: `Paras::MostRecentContext` (r:0 w:1)
@@ -96,8 +96,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 3_761_000 picoseconds.
-		Weight::from_parts(3_967_000, 0)
+		// Minimum execution time: 3_536_000 picoseconds.
+		Weight::from_parts(3_801_000, 0)
 			.saturating_add(Weight::from_parts(0, 0))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
@@ -124,11 +124,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `8452`
 		//  Estimated: `11917`
-		// Minimum execution time: 50_203_000 picoseconds.
-		Weight::from_parts(51_545_000, 0)
+		// Minimum execution time: 50_575_000 picoseconds.
+		Weight::from_parts(51_394_000, 0)
 			.saturating_add(Weight::from_parts(0, 11917))
-			// Standard Error: 99
-			.saturating_add(Weight::from_parts(11_128, 0).saturating_mul(c.into()))
+			// Standard Error: 131
+			.saturating_add(Weight::from_parts(13_681, 0).saturating_mul(c.into()))
 			.saturating_add(T::DbWeight::get().reads(8))
 			.saturating_add(T::DbWeight::get().writes(7))
 	}
@@ -147,11 +147,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `299`
 		//  Estimated: `3764`
-		// Minimum execution time: 19_332_000 picoseconds.
-		Weight::from_parts(19_815_000, 0)
+		// Minimum execution time: 18_610_000 picoseconds.
+		Weight::from_parts(19_386_000, 0)
 			.saturating_add(Weight::from_parts(0, 3764))
-			// Standard Error: 34
-			.saturating_add(Weight::from_parts(3_843, 0).saturating_mul(s.into()))
+			// Standard Error: 43
+			.saturating_add(Weight::from_parts(4_602, 0).saturating_mul(s.into()))
 			.saturating_add(T::DbWeight::get().reads(2))
 			.saturating_add(T::DbWeight::get().writes(3))
 	}
@@ -163,8 +163,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `4312`
 		//  Estimated: `7777`
-		// Minimum execution time: 21_673_000 picoseconds.
-		Weight::from_parts(23_218_000, 0)
+		// Minimum execution time: 21_417_000 picoseconds.
+		Weight::from_parts(21_849_000, 0)
 			.saturating_add(Weight::from_parts(0, 7777))
 			.saturating_add(T::DbWeight::get().reads(2))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -182,11 +182,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `683`
 		//  Estimated: `4148`
-		// Minimum execution time: 84_062_000 picoseconds.
-		Weight::from_parts(84_913_000, 0)
+		// Minimum execution time: 87_281_000 picoseconds.
+		Weight::from_parts(89_737_000, 0)
 			.saturating_add(Weight::from_parts(0, 4148))
-			// Standard Error: 96
-			.saturating_add(Weight::from_parts(10_315, 0).saturating_mul(c.into()))
+			// Standard Error: 126
+			.saturating_add(Weight::from_parts(12_980, 0).saturating_mul(c.into()))
 			.saturating_add(T::DbWeight::get().reads(4))
 			.saturating_add(T::DbWeight::get().writes(3))
 	}
@@ -198,8 +198,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `28`
 		//  Estimated: `3493`
-		// Minimum execution time: 7_340_000 picoseconds.
-		Weight::from_parts(7_607_000, 0)
+		// Minimum execution time: 7_018_000 picoseconds.
+		Weight::from_parts(7_255_000, 0)
 			.saturating_add(Weight::from_parts(0, 3493))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -214,8 +214,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `26706`
 		//  Estimated: `30171`
-		// Minimum execution time: 105_607_000 picoseconds.
-		Weight::from_parts(111_765_000, 0)
+		// Minimum execution time: 107_361_000 picoseconds.
+		Weight::from_parts(112_503_000, 0)
 			.saturating_add(Weight::from_parts(0, 30171))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -236,8 +236,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `27360`
 		//  Estimated: `30825`
-		// Minimum execution time: 722_925_000 picoseconds.
-		Weight::from_parts(735_471_000, 0)
+		// Minimum execution time: 739_794_000 picoseconds.
+		Weight::from_parts(770_941_000, 0)
 			.saturating_add(Weight::from_parts(0, 30825))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(103))
@@ -252,8 +252,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `27338`
 		//  Estimated: `30803`
-		// Minimum execution time: 105_772_000 picoseconds.
-		Weight::from_parts(110_745_000, 0)
+		// Minimum execution time: 105_596_000 picoseconds.
+		Weight::from_parts(108_616_000, 0)
 			.saturating_add(Weight::from_parts(0, 30803))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -272,8 +272,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `26728`
 		//  Estimated: `30193`
-		// Minimum execution time: 597_009_000 picoseconds.
-		Weight::from_parts(610_992_000, 0)
+		// Minimum execution time: 602_259_000 picoseconds.
+		Weight::from_parts(619_727_000, 0)
 			.saturating_add(Weight::from_parts(0, 30193))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(3))
@@ -288,26 +288,26 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `26706`
 		//  Estimated: `30171`
-		// Minimum execution time: 102_474_000 picoseconds.
-		Weight::from_parts(107_025_000, 0)
+		// Minimum execution time: 100_521_000 picoseconds.
+		Weight::from_parts(107_587_000, 0)
 			.saturating_add(Weight::from_parts(0, 30171))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
 	/// Storage: `Paras::AuthorizedCodeHash` (r:1 w:1)
-	/// Proof: `Paras::AuthorizedCodeHash` (`max_values`: None, `max_size`: None, mode: `Measured`)
+	/// Proof: `Paras::AuthorizedCodeHash` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
 	fn authorize_code_hash() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `28`
-		//  Estimated: `3493`
-		// Minimum execution time: 11_572_000 picoseconds.
-		Weight::from_parts(12_296_000, 0)
-			.saturating_add(Weight::from_parts(0, 3493))
+		//  Estimated: `1513`
+		// Minimum execution time: 10_250_000 picoseconds.
+		Weight::from_parts(10_652_000, 0)
+			.saturating_add(Weight::from_parts(0, 1513))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
 	/// Storage: `Paras::AuthorizedCodeHash` (r:1 w:1)
-	/// Proof: `Paras::AuthorizedCodeHash` (`max_values`: None, `max_size`: None, mode: `Measured`)
+	/// Proof: `Paras::AuthorizedCodeHash` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
 	/// Storage: `Paras::CodeByHashRefs` (r:1 w:1)
 	/// Proof: `Paras::CodeByHashRefs` (`max_values`: None, `max_size`: None, mode: `Measured`)
 	/// Storage: `Paras::CurrentCodeHash` (r:1 w:1)
@@ -319,11 +319,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `126`
 		//  Estimated: `3591`
-		// Minimum execution time: 28_673_000 picoseconds.
-		Weight::from_parts(29_274_000, 0)
+		// Minimum execution time: 27_575_000 picoseconds.
+		Weight::from_parts(28_535_000, 0)
 			.saturating_add(Weight::from_parts(0, 3591))
-			// Standard Error: 103
-			.saturating_add(Weight::from_parts(12_057, 0).saturating_mul(c.into()))
+			// Standard Error: 131
+			.saturating_add(Weight::from_parts(14_711, 0).saturating_mul(c.into()))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(4))
 	}
diff --git a/polkadot/runtime/westend/src/weights/polkadot_runtime_parachains_paras.rs b/polkadot/runtime/westend/src/weights/polkadot_runtime_parachains_paras.rs
index d855ab1eed92483d7bc6605cf71f41aa9745e456..7700f4b37efae88de56259ee69ff0e9c256e9696 100644
--- a/polkadot/runtime/westend/src/weights/polkadot_runtime_parachains_paras.rs
+++ b/polkadot/runtime/westend/src/weights/polkadot_runtime_parachains_paras.rs
@@ -17,9 +17,9 @@
 //! Autogenerated weights for `polkadot_runtime_parachains::paras`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 32.0.0
-//! DATE: 2025-02-17, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! DATE: 2025-02-27, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
 //! WORST CASE MAP SIZE: `1000000`
-//! HOSTNAME: `10b335e74d87`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
+//! HOSTNAME: `79347b363bdd`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
 //! WASM-EXECUTION: `Compiled`, CHAIN: `None`, DB CACHE: 1024
 
 // Executed Command:
@@ -68,11 +68,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `8309`
 		//  Estimated: `11774`
-		// Minimum execution time: 38_665_000 picoseconds.
-		Weight::from_parts(39_249_000, 0)
+		// Minimum execution time: 36_848_000 picoseconds.
+		Weight::from_parts(38_037_000, 0)
 			.saturating_add(Weight::from_parts(0, 11774))
-			// Standard Error: 98
-			.saturating_add(Weight::from_parts(10_779, 0).saturating_mul(c.into()))
+			// Standard Error: 97
+			.saturating_add(Weight::from_parts(10_714, 0).saturating_mul(c.into()))
 			.saturating_add(T::DbWeight::get().reads(4))
 			.saturating_add(T::DbWeight::get().writes(6))
 	}
@@ -83,11 +83,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 7_324_000 picoseconds.
-		Weight::from_parts(7_514_000, 0)
+		// Minimum execution time: 6_844_000 picoseconds.
+		Weight::from_parts(6_947_000, 0)
 			.saturating_add(Weight::from_parts(0, 0))
-			// Standard Error: 31
-			.saturating_add(Weight::from_parts(3_853, 0).saturating_mul(s.into()))
+			// Standard Error: 33
+			.saturating_add(Weight::from_parts(3_880, 0).saturating_mul(s.into()))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
 	/// Storage: `Paras::MostRecentContext` (r:0 w:1)
@@ -96,8 +96,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 3_709_000 picoseconds.
-		Weight::from_parts(3_907_000, 0)
+		// Minimum execution time: 3_468_000 picoseconds.
+		Weight::from_parts(3_708_000, 0)
 			.saturating_add(Weight::from_parts(0, 0))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
@@ -124,11 +124,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `8452`
 		//  Estimated: `11917`
-		// Minimum execution time: 53_140_000 picoseconds.
-		Weight::from_parts(54_370_000, 0)
+		// Minimum execution time: 51_536_000 picoseconds.
+		Weight::from_parts(52_781_000, 0)
 			.saturating_add(Weight::from_parts(0, 11917))
-			// Standard Error: 99
-			.saturating_add(Weight::from_parts(10_765, 0).saturating_mul(c.into()))
+			// Standard Error: 97
+			.saturating_add(Weight::from_parts(10_726, 0).saturating_mul(c.into()))
 			.saturating_add(T::DbWeight::get().reads(8))
 			.saturating_add(T::DbWeight::get().writes(7))
 	}
@@ -145,11 +145,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `268`
 		//  Estimated: `3733`
-		// Minimum execution time: 15_440_000 picoseconds.
-		Weight::from_parts(15_803_000, 0)
+		// Minimum execution time: 14_371_000 picoseconds.
+		Weight::from_parts(14_746_000, 0)
 			.saturating_add(Weight::from_parts(0, 3733))
-			// Standard Error: 31
-			.saturating_add(Weight::from_parts(3_875, 0).saturating_mul(s.into()))
+			// Standard Error: 32
+			.saturating_add(Weight::from_parts(3_910, 0).saturating_mul(s.into()))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(3))
 	}
@@ -161,8 +161,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `4312`
 		//  Estimated: `7777`
-		// Minimum execution time: 25_196_000 picoseconds.
-		Weight::from_parts(26_741_000, 0)
+		// Minimum execution time: 24_060_000 picoseconds.
+		Weight::from_parts(25_218_000, 0)
 			.saturating_add(Weight::from_parts(0, 7777))
 			.saturating_add(T::DbWeight::get().reads(2))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -180,11 +180,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `683`
 		//  Estimated: `4148`
-		// Minimum execution time: 89_459_000 picoseconds.
-		Weight::from_parts(92_650_000, 0)
+		// Minimum execution time: 87_440_000 picoseconds.
+		Weight::from_parts(89_866_000, 0)
 			.saturating_add(Weight::from_parts(0, 4148))
-			// Standard Error: 96
-			.saturating_add(Weight::from_parts(10_376, 0).saturating_mul(c.into()))
+			// Standard Error: 93
+			.saturating_add(Weight::from_parts(10_639, 0).saturating_mul(c.into()))
 			.saturating_add(T::DbWeight::get().reads(4))
 			.saturating_add(T::DbWeight::get().writes(3))
 	}
@@ -196,8 +196,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `28`
 		//  Estimated: `3493`
-		// Minimum execution time: 7_259_000 picoseconds.
-		Weight::from_parts(7_669_000, 0)
+		// Minimum execution time: 6_893_000 picoseconds.
+		Weight::from_parts(7_154_000, 0)
 			.saturating_add(Weight::from_parts(0, 3493))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -212,8 +212,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `26706`
 		//  Estimated: `30171`
-		// Minimum execution time: 113_848_000 picoseconds.
-		Weight::from_parts(121_448_000, 0)
+		// Minimum execution time: 111_526_000 picoseconds.
+		Weight::from_parts(133_072_000, 0)
 			.saturating_add(Weight::from_parts(0, 30171))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -234,8 +234,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `27360`
 		//  Estimated: `30825`
-		// Minimum execution time: 718_903_000 picoseconds.
-		Weight::from_parts(734_602_000, 0)
+		// Minimum execution time: 740_026_000 picoseconds.
+		Weight::from_parts(776_301_000, 0)
 			.saturating_add(Weight::from_parts(0, 30825))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(103))
@@ -250,8 +250,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `27338`
 		//  Estimated: `30803`
-		// Minimum execution time: 115_265_000 picoseconds.
-		Weight::from_parts(125_827_000, 0)
+		// Minimum execution time: 109_240_000 picoseconds.
+		Weight::from_parts(129_275_000, 0)
 			.saturating_add(Weight::from_parts(0, 30803))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -270,8 +270,8 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `26728`
 		//  Estimated: `30193`
-		// Minimum execution time: 585_643_000 picoseconds.
-		Weight::from_parts(603_584_000, 0)
+		// Minimum execution time: 591_032_000 picoseconds.
+		Weight::from_parts(615_374_000, 0)
 			.saturating_add(Weight::from_parts(0, 30193))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(3))
@@ -286,26 +286,26 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `26706`
 		//  Estimated: `30171`
-		// Minimum execution time: 112_189_000 picoseconds.
-		Weight::from_parts(117_113_000, 0)
+		// Minimum execution time: 107_013_000 picoseconds.
+		Weight::from_parts(127_959_000, 0)
 			.saturating_add(Weight::from_parts(0, 30171))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
 	/// Storage: `Paras::AuthorizedCodeHash` (r:1 w:1)
-	/// Proof: `Paras::AuthorizedCodeHash` (`max_values`: None, `max_size`: None, mode: `Measured`)
+	/// Proof: `Paras::AuthorizedCodeHash` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
 	fn authorize_code_hash() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `28`
-		//  Estimated: `3493`
-		// Minimum execution time: 11_616_000 picoseconds.
-		Weight::from_parts(12_175_000, 0)
-			.saturating_add(Weight::from_parts(0, 3493))
+		//  Estimated: `1513`
+		// Minimum execution time: 9_579_000 picoseconds.
+		Weight::from_parts(10_266_000, 0)
+			.saturating_add(Weight::from_parts(0, 1513))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
 	/// Storage: `Paras::AuthorizedCodeHash` (r:1 w:1)
-	/// Proof: `Paras::AuthorizedCodeHash` (`max_values`: None, `max_size`: None, mode: `Measured`)
+	/// Proof: `Paras::AuthorizedCodeHash` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
 	/// Storage: `Paras::CodeByHashRefs` (r:1 w:1)
 	/// Proof: `Paras::CodeByHashRefs` (`max_values`: None, `max_size`: None, mode: `Measured`)
 	/// Storage: `Paras::CurrentCodeHash` (r:1 w:1)
@@ -317,11 +317,11 @@ impl<T: frame_system::Config> polkadot_runtime_parachains::paras::WeightInfo for
 		// Proof Size summary in bytes:
 		//  Measured:  `126`
 		//  Estimated: `3591`
-		// Minimum execution time: 28_018_000 picoseconds.
-		Weight::from_parts(28_734_000, 0)
+		// Minimum execution time: 31_189_000 picoseconds.
+		Weight::from_parts(32_054_000, 0)
 			.saturating_add(Weight::from_parts(0, 3591))
 			// Standard Error: 102
-			.saturating_add(Weight::from_parts(12_655, 0).saturating_mul(c.into()))
+			.saturating_add(Weight::from_parts(12_396, 0).saturating_mul(c.into()))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(4))
 	}